@@ -29,7 +29,9 @@ sub _option_popup {
     if (! @rv) { # no elements returned, while we expect one; create the popup
         # make sure the popup gets created by clicking twice (pop up+pop down)
         $self->click;
-        $self->click;
+        # wait until the popup has been created!
+        $page->find("//div[\@dijitpopupparent='$id']");
+        $self->click; # hide the popup again
 
         @rv = $page->find_all("//div[\@dijitpopupparent='$id']");
     }
@@ -37,6 +39,17 @@ sub _option_popup {
     return (shift @rv);
 }
 
+sub get_attribute {
+    my ($self, $name) = @_;
 
+    if ($name eq 'value') {
+        return $self->find('.//input[@type="hidden"
+                              and @data-dojo-attach-point="valueNode"]')
+            ->get_attribute('value');
+    }
+    else {
+        return $self->SUPER::get_attribute($name);
+    }
+}
 
 1;
